@@ -23,16 +23,15 @@
 #' condformat(iris[c(1:5, 70:75, 120:125), ]) +
 #'  rule_fill_discrete(Species, colours = c("setosa" = "red",
 #'                                          "versicolor" = "blue",
-#'                                          "virginica" = "green"))
-#' condformat(iris[c(1:5, 70:75, 120:125), ]) +
-#'  rule_fill_discrete(Species, expression=Sepal.Length > 4.6,
+#'                                          "virginica" = "green")) +
+#'  rule_fill_discrete(Sepal.Length, expression=Sepal.Length > 4.6,
 #'                     colours=c("TRUE"="red"))
 #' @export
 #' @importFrom lazyeval lazy_dots lazy
 rule_fill_discrete <- function(...,
                                expression,
                                colours,
-                               na.value = "blank",
+                               na.value = "#FFFFFF",
                                h = c(0, 360) + 15, c = 100, l = 65,
                                h.start = 0, direction = 1,
                                lockcells=FALSE) {
@@ -71,7 +70,7 @@ rule_fill_discrete_ <- function(columns,
                                 expression,
                                 colours,
                                 h = c(0, 360) + 15, c = 100, l = 65,
-                                h.start = 0, direction = 1, na.value = "blank",
+                                h.start = 0, direction = 1, na.value = "#FFFFFF",
                                 lockcells=FALSE,
                                 env=parent.frame()) {
   if (missing(expression)) {
