@@ -1,7 +1,4 @@
 # Tests:
-library(condformat)
-library(dplyr)
-library(testthat)
 context("rule_fill_gradient")
 
 test_that("rule_fill_gradient works", {
@@ -9,11 +6,11 @@ test_that("rule_fill_gradient works", {
   x <- condformat(iris[c(1:10, 51:60, 101:110),])
   y <- x + rule_fill_gradient(Sepal.Length)
   out <- condformat2html(y)
-  expect_that(out[1], matches("^<table.*</table>$"))
+  expect_match(out, "^<table.*</table>$")
 
   y <- x + rule_fill_gradient_("Sepal.Length")
   out <- condformat2html(y)
-  expect_that(out[1], matches("^<table.*</table>$"))
+  expect_match(out, "^<table.*</table>$")
 })
 
 test_that("rule_fill_gradient2 works", {
@@ -21,10 +18,10 @@ test_that("rule_fill_gradient2 works", {
   x <- condformat(iris[c(1:10, 51:60, 101:110),])
   y <- x + rule_fill_gradient2(Sepal.Length)
   out <- condformat2html(y)
-  expect_that(out[1], matches("^<table.*</table>$"))
+  expect_match(out, "^<table.*</table>$")
 
   y <- x + rule_fill_gradient2_("Sepal.Length")
   out <- condformat2html(y)
-  expect_that(out[1], matches("^<table.*</table>$"))
+  expect_match(out, "^<table.*</table>$")
 })
 
